@@ -448,14 +448,37 @@ def air_comparison_v1(lat, lon, start = 1606488670, end = 1606747870, col = "no"
     future_level = transfer_df(lat,lon)
     history_level = transfer_df(lat,lon,start,end)
         
-    if mean(forcast_level[col]) > mean(hist_pollution_level[col]):
+    if mean(future_level[col]) > mean(hist_pollution_level[col]):
         return f'The {col} for this location will be increasing in the future'
-    if mean(forcast_level[col]) < mean(hist_pollution_level[col]):
+    if mean(future_level[col]) < mean(hist_pollution_level[col]):
         return f'The {col} for this location will be decreasing in the future'
-    if mean(forcast_level[col]) == mean(hist_pollution_level[col]):
+    if mean(future_level[col]) == mean(hist_pollution_level[col]):
         return f'The {col} for this location will stay the same in the future'
     
 def comparison(lat, lon, start = 1606488670, end = 1606747870):
+    """
+    This function can visualize the future, history, or overall air pollution level among time, it is created for having a overlook of the pollution chages.
+    
+    Parameter
+    ----------
+    lat: Geographical coordinates (latitude)
+    lon: Geographical coordinates (lontitude)
+    start: Start date (unix time, UTC time zone), e.g. start=1606488670, only used when CFT = 'history'
+    end: End date (unix time, UTC time zone), e.g. end=1606747870, only used when CFT = 'history'
+    
+    Examples
+    ----------
+    >>> comparison(lat = 20, lon = 10)
+    '['The co for this location will be increasing in the future',
+ 'The no for this location will be increasing in the future',
+ 'The no2 for this location will be decreasing in the future',
+ 'The o3 for this location will be decreasing in the future',
+ 'The so2 for this location will be increasing in the future',
+ 'The pm2_5 for this location will be increasing in the future',
+ 'The pm10 for this location will be increasing in the future',
+ 'The nh3 for this location will be decreasing in the future',
+ 'The total_level for this location will be decreasing in the future']'
+    """
     
     assert lon < 181, "Your lontitude has above the range."
     assert lat < 91, "Your latitude has abouve the range."
